@@ -7,7 +7,7 @@ use MooseX::StrictConstructor      ();
 use App::GHPT::Wrapper::Ourperl;
 
 use Import::Into;
-use Test::Class::Moose                    ();
+use Test::Class::Moose 0.82 ();
 use Test::Class::Moose::AttributeRegistry ();
 use Test::More;
 use namespace::autoclean ();
@@ -19,7 +19,7 @@ sub import {
     Test::Class::Moose->import::into($caller_level);
 
     MooseX::SemiAffordanceAccessor->import( { into => $for_class } );
-    MooseX::StrictConstructor->import( { into => $for_class } );
+    MooseX::StrictConstructor->import(      { into => $for_class } );
 
     App::GHPT::Wrapper::Ourperl->import::into($caller_level);
     namespace::autoclean->import::into($caller_level);
